.. _module_ext_client_core_tkimport:

tkimport
========

This sections contains module documentation of tkimport module.

Module imports used tkinter modules (according to Python version) and sets common aliases.